Dev notes
=========

This directory is for records of reasoning and decisions taken in the course of development.

Notes should be organised by task and focus on details that are beyond the granularity of the original design or task description.
